@@ -3,8 +3,6 @@
 
 """Specific versions of XWorkflows to use with Django."""
 
-import datetime
-
 from django.db import models
 from django.db import transaction
 from django.conf import settings
@@ -16,6 +14,15 @@ from django.forms import widgets
 from django.utils.encoding import force_unicode
 from django.utils.translation import ugettext_lazy as _
 
+try:
+    from django.utils import timezone
+    now = timezone.now
+    del timezone
+except ImportError:
+    import datetime
+    now = datetime.datetime.now
+    del datetime
+
 from xworkflows import base
 
 
@@ -80,12 +87,18 @@ class StateField(models.Field):
     }
     description = _(u"State")
 
+    DEFAULT_MAX_LENGTH = 16
+
     def __init__(self, workflow, **kwargs):
         if isinstance(workflow, type):
             workflow = workflow()
         self.workflow = workflow
-        kwargs['choices'] = list((st.name, st.title) for st in self.workflow.states)
-        kwargs['max_length'] = max(len(st.name) for st in self.workflow.states)
+        kwargs['choices'] = list(
+            (st.name, st.title) for st in self.workflow.states)
+
+        kwargs['max_length'] = max(
+            kwargs.get('max_length', self.DEFAULT_MAX_LENGTH),
+            max(len(st.name) for st in self.workflow.states))
         kwargs['blank'] = False
         kwargs['null'] = False
         kwargs['default'] = self.workflow.initial_state.name
@@ -263,7 +276,7 @@ class BaseTransitionLog(models.Model):
     to_state = models.CharField(_(u"to state"), max_length=255,
         db_index=True)
     timestamp = models.DateTimeField(_(u"performed at"),
-        default=datetime.datetime.now, db_index=True)
+        default=now, db_index=True)
 
     class Meta:
         ordering = ('-timestamp', 'transition')
